#ifndef NT2_CORE_INCLUDE_FUNCTIONS_IND2SUB_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_IND2SUB_HPP_INCLUDED

#include <nt2/core/functions/ind2sub.hpp>
#include <nt2/core/functions/common/ind2sub.hpp>
#include <nt2/core/functions/expr/ind2sub.hpp>
#include <nt2/core/functions/scalar/ind2sub.hpp>

#endif
